/*
 * compression.h - routines for compressing and decompressing Steiner triple
 *                 systems
 *
 * Copyright (c) 2008, 2014 Petteri Kaski, Patric Ostergard, Olli Pottonen
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

#ifndef COMPRESSION_H
#define COMPRESSION_H

#include <stdio.h>
#include <stdint.h>

/***************************** Number of points, pairs of points, and blocks */

#define STS_V  19
#define STS_P  (STS_V*(STS_V-1)/2)
#define STS_B  ((STS_V*(STS_V-1))/6)

/*************************************************** Decompression interface */

typedef struct file_r_s file_r;

file_r     * init_decompress  (FILE *);
const int  * decompress       (file_r *);
void         free_decompress  (file_r *);
void         open_set         (file_r *, int);
/* Each of these return a 32-bit unsigned int. */
unsigned int get_sts_count    (const file_r *);
unsigned int get_set_size     (const file_r *);
unsigned int get_offset       (const file_r *);

/***************************************************** Compression interface */

typedef struct file_w_s file_w;

file_w * init_compress  (FILE *, int blocksize);
void     compress       (const int *, file_w *);
void     free_compress  (file_w *w);

#endif // COMPRESSION_H
